Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AggregatedClient ¶
type AggregatedClient struct {
OrganizationURL string
CoreClient core.Client
BuildClient build.Client
PipelinesClient pipelines.Client
GitReposClient git.Client
GraphClient graph.Client
OperationsClient operations.Client
PipelinesChecksClient pipelineschecks.Client
PipelinePermissionsClient pipelinepermissions.Client
PipelinesChecksClientExtras pipelineschecksextras.Client
PolicyClient policy.Client
ElasticClient elastic.Client
ReleaseClient release.Client
ServiceEndpointClient serviceendpoint.Client
TaskAgentClient taskagent.Client
MemberEntitleManagementClient memberentitlementmanagement.Client
FeatureManagementClient featuremanagement.Client
SecurityClient security.Client
IdentityClient identity.Client
WorkItemTrackingClient workitemtracking.Client
ServiceHooksClient servicehooks.Client
Ctx context.Context
}
AggregatedClient aggregates all of the underlying clients into a single data type. Each client is ready to use and fully configured with the correct AzDO PAT/organization
AggregatedClient uses interfaces derived from the underlying client structs to allow for mocking to support unit testing of the funcs that invoke the Azure DevOps client.
func GetAzdoClient ¶
func GetAzdoClient(azdoTokenProvider func() (string, error), organizationURL string, tfVersion string) (*AggregatedClient, error)
GetAzdoClient builds and provides a connection to the Azure DevOps API
Click to show internal directories.
Click to hide internal directories.